Translations class
- Mixed-in types
- Implementers
Constructors
-
Translations({Map<
String, Node> ? overrides, PluralResolver? cardinalResolver, PluralResolver? ordinalResolver, TranslationMetadata<AppLocale, Translations> ? meta}) - You can call this constructor and build your own translation instance of this locale. Constructing via the enum AppLocale.build is preferred.
Properties
-
$meta
→ TranslationMetadata<
AppLocale, Translations> -
Metadata for the translations of
final
- $wip → dynamic
-
Provides the ability to write plain strings without code generation.
Useful for prototyping / development.
no setterinherited
- account → TranslationsAccountEn
-
latefinal
- app_config → TranslationsAppConfigEn
-
latefinal
- auth → TranslationsAuthEn
-
latefinal
- common → TranslationsCommonEn
-
latefinal
- datetime → TranslationsDatetimeEn
-
latefinal
- device_info → TranslationsDeviceInfoEn
-
latefinal
- download → TranslationsDownloadEn
-
latefinal
- empty_view → TranslationsEmptyViewEn
-
latefinal
- error → TranslationsErrorEn
-
latefinal
- force_update → TranslationsForceUpdateEn
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpers → TranslationsHelpersEn
-
latefinal
- hivece_storage → TranslationsHiveceStorageEn
-
latefinal
- home → TranslationsHomeEn
-
latefinal
- image_detail → TranslationsImageDetailEn
-
latefinal
- loading → TranslationsLoadingEn
-
latefinal
- onboarding → TranslationsOnboardingEn
-
latefinal
- package_info → TranslationsPackageInfoEn
-
latefinal
- permissions → TranslationsPermissionsEn
-
latefinal
- permissions_helper → TranslationsPermissionsHelperEn
-
latefinal
- products → TranslationsProductsEn
-
latefinal
- profile → TranslationsProfileEn
-
latefinal
- push_notification → TranslationsPushNotificationEn
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → TranslationsSearchEn
-
latefinal
- settings → TranslationsSettingsEn
-
latefinal
- settings_widgets → TranslationsSettingsWidgetsEn
-
latefinal
-
latefinal
- skeleton → TranslationsSkeletonEn
-
latefinal
- splash → TranslationsSplashEn
-
latefinal
- storage → TranslationsStorageEn
-
latefinal
- svg_helper → TranslationsSvgHelperEn
-
latefinal
- url_launcher → TranslationsUrlLauncherEn
-
latefinal
- web_viewer → TranslationsWebViewerEn
-
latefinal
Methods
-
$copyWith(
{TranslationMetadata< AppLocale, Translations> ? meta}) → Translations -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → dynamic - Access flat map
Static Methods
-
of(
BuildContext context) → Translations -
Returns the current translations of the given
context.