TranslationsAppConfigEn class

Properties

api_configuration String
en: 'apiConfiguration'
no setter
app_settings String
en: 'appSettings'
no setter
config_file_path String
en: 'assets/app_config.json'
no setter
hashCode int
The hash code for this object.
no setterinherited
items String
en: 'items'
no setter
keys String
en: 'keys'
no setter
null_value String
en: 'null'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splash_configuration String
en: 'splashConfiguration'
no setter
storage_configuration String
en: 'storageConfiguration'
no setter
title String
en: 'App Config'
no setter
ui_configuration String
en: 'uiConfiguration'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited