TranslationsAuthEn class

Properties

email String
en: 'Email'
no setter
forgot_password String
en: 'Forgot Password?'
no setter
hashCode int
The hash code for this object.
no setterinherited
password String
en: 'Password'
no setter
remember_me String
en: 'Remember me'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sign_in String
en: 'Sign In'
no setter
sign_in_failed String
en: 'Sign in failed'
no setter
sign_up String
en: 'Sign Up'
no setter
sign_up_failed String
en: 'Sign up failed'
no setter
title String
en: 'Authentication'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited