TranslationsDatetimeEn class
Properties
- format_date → String
-
en: 'formatDate()'
no setter
- format_datetime → String
-
en: 'formatDateTime()'
no setter
- format_time → String
-
en: 'formatTime()'
no setter
- get_relative_time → String
-
en: 'getRelativeTime()'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- parse_date → String
-
en: 'parseDate()'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
en: 'DateTime'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited