TranslationsDeviceInfoEn class

Properties

device_id String
en: 'device_id'
no setter
device_name String
en: 'device_name'
no setter
hashCode int
The hash code for this object.
no setterinherited
manufacturer String
en: 'manufacturer'
no setter
model String
en: 'model'
no setter
platform String
en: 'platform'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
system_version String
en: 'system_version'
no setter
title String
en: 'Device Info'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited