TranslationsDownloadEn class

Properties

download_file String
en: 'Download File'
no setter
filename String
en: 'Filename'
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
en: 'Download'
no setter
url String
en: 'URL'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited