TranslationsErrorEn class

Properties

error_code String
en: 'Error Code'
no setter
generic String
en: 'Something went wrong. Please try again.'
no setter
hashCode int
The hash code for this object.
no setterinherited
network String
en: 'Network error. Please check your connection.'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unauthorized String
en: 'You are not authorized to perform this action.'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited