masterview_cubit_desc property

String get masterview_cubit_desc

en: 'Base view class with integrated Cubit state management, lifecycle hooks, and common UI patterns.'

Implementation

String get masterview_cubit_desc => 'Base view class with integrated Cubit state management, lifecycle hooks, and common UI patterns.';