TranslationsOnboardingEn class
Properties
- get_started → String
-
en: 'Get Started'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- next → String
-
en: 'Next'
no setter
- no_pages_configured → String
-
en: 'No onboarding pages configured'
no setter
- previous → String
-
en: 'Previous'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skip → String
-
en: 'Skip'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited