TranslationsPermissionsEn class

Properties

denied String
en: 'Permission Denied'
no setter
description String
en: 'This app needs certain permissions to function properly.'
no setter
grant String
en: 'Grant'
no setter
grant_all String
en: 'Grant All Permissions'
no setter
hashCode int
The hash code for this object.
no setterinherited
request_permissions String
en: 'Request Permissions'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
en: 'Permissions Required'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited