TranslationsPermissionsHelperEn class

Properties

denied String
en: 'denied'
no setter
granted String
en: 'granted'
no setter
hashCode int
The hash code for this object.
no setterinherited
request String
en: 'Request'
no setter
runtime_permissions String
en: 'Runtime Permissions'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
en: 'Permissions'
no setter
unknown String
en: 'unknown'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited