TranslationsProfileEn class
Properties
- actions → String
-
en: 'Actions'
no setter
- device → String
-
en: 'Device'
no setter
- device_id → String
-
en: 'device_id'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- manufacturer → String
-
en: 'manufacturer'
no setter
- platform → String
-
en: 'platform'
no setter
-
en: 'Profile view is hidden'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show_profile_view → String
-
en: 'Show Profile View'
no setter
- title → String
-
en: 'Profile'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited