TranslationsPushNotificationEn class
Properties
- actions → String
-
en: 'Actions'
no setter
- active_providers → String
-
en: 'Active Providers'
no setter
- clear_all_data → String
-
en: 'Clear All Data'
no setter
- custom → String
-
en: 'Custom'
no setter
- device_tokens → String
-
en: 'Device Tokens'
no setter
- enter_topic_name → String
-
en: 'Enter topic name'
no setter
- enter_user_id → String
-
en: 'Enter user ID'
no setter
- firebase → String
-
en: 'Firebase'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialize_to_check_permissions → String
-
en: 'Initialize to check permissions'
no setter
- initialize_to_see_providers → String
-
en: 'Initialize to see active providers'
no setter
- initialize_to_see_tokens → String
-
en: 'Initialize to see device tokens'
no setter
- initialized → String
-
en: 'Initialized'
no setter
- no_providers_configured → String
-
en: 'No providers configured'
no setter
- no_token → String
-
en: 'No token'
no setter
- no_topics_subscribed → String
-
en: 'No topics subscribed'
no setter
- not_initialized → String
-
en: 'Not Initialized'
no setter
- onesignal → String
-
en: 'OneSignal'
no setter
- opt_in → String
-
en: 'Opt In'
no setter
- opt_out → String
-
en: 'Opt Out'
no setter
- permissions → String
-
en: 'Permissions'
no setter
- providers_active → String
-
en: 'provider(s) active'
no setter
- remove_user_id → String
-
en: 'Remove User ID (Logout)'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- set → String
-
en: 'Set'
no setter
- status → String
-
en: 'Status'
no setter
- subscribe → String
-
en: 'Subscribe'
no setter
- tap_to_initialize → String
-
en: 'Tap to initialize'
no setter
- title → String
-
en: 'Push Notifications'
no setter
- token_copied → String
-
en: 'Token copied to clipboard'
no setter
- topic_subscriptions → String
-
en: 'Topic Subscriptions'
no setter
- user_targeting → String
-
en: 'User Targeting'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited