TranslationsSettingsWidgetsEn class

Properties

hashCode int
The hash code for this object.
no setterinherited
reset String
en: 'Reset'
no setter
reset_dialog_content String
en: 'This will reset all theme settings to their default values. This action cannot be undone.'
no setter
reset_dialog_title String
en: 'Reset to Defaults'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
show_icons String
en: 'Show Icons'
no setter
toggle_icon_visibility String
en: 'Toggle icon visibility globally'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited