TranslationsShareEn class

Properties

enter_text String
en: 'Enter text'
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
share_file String
en: 'Share File'
no setter
share_text String
en: 'Share Text'
no setter
title String
en: 'Share'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited