TranslationsSkeletonEn class

Properties

animation String
en: 'Animation:'
no setter
article String
en: 'Article'
no setter
avatar_shapes String
en: 'Avatar Shapes'
no setter
basic_shapes String
en: 'Basic Shapes'
no setter
cards String
en: 'Cards'
no setter
circle String
en: 'Circle'
no setter
color_themes String
en: 'Color Themes'
no setter
custom_shapes String
en: 'Custom Shapes'
no setter
dark String
en: 'Dark'
no setter
dark_theme String
en: 'Dark Theme'
no setter
diamond String
en: 'Diamond'
no setter
hashCode int
The hash code for this object.
no setterinherited
hexagon String
en: 'Hexagon'
no setter
large String
en: 'Large'
no setter
light String
en: 'Light'
no setter
list_items String
en: 'List Items'
no setter
medium String
en: 'Medium'
no setter
paragraph String
en: 'Paragraph'
no setter
product_cards String
en: 'Product Cards'
no setter
profile String
en: 'Profile'
no setter
rectangle String
en: 'Rectangle'
no setter
rounded String
en: 'Rounded'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small String
en: 'Small'
no setter
social_post String
en: 'Social Post'
no setter
star String
en: 'Star'
no setter
stories String
en: 'Stories'
no setter
text_line String
en: 'Text Line'
no setter
text_shapes String
en: 'Text Shapes'
no setter
theme String
en: 'Theme:'
no setter
title String
en: 'Skeleton Helper'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited