TranslationsSplashEn class
Properties
- empty → String
-
en: 'No data available'
no setter
- error → String
-
en: 'Error occurred'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- loading → String
-
en: 'Loading...'
no setter
- maintenance → String
-
en: 'Under maintenance'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → String
-
en: 'Request timeout'
no setter
-
en: 'Unauthorized'
no setter
- webview → String
-
en: 'Webview'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited