TranslationsStorageEn class

Properties

bool String
en: 'Bool'
no setter
double String
en: 'Double'
no setter
false_value String
en: 'false'
no setter
hashCode int
The hash code for this object.
no setterinherited
int String
en: 'Int'
no setter
key String
en: 'key'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string String
en: 'String'
no setter
title String
en: 'Local Storage'
no setter
true_value String
en: 'true'
no setter
value String
en: 'value'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited