TranslationsEs class
- Implemented types
-
- Mixed-in types
-
Properties
-
$meta
→ TranslationMetadata<AppLocale, Translations>
-
Metadata for the translations of
final
-
$wip
→ dynamic
-
Provides the ability to write plain strings without code generation.
Useful for prototyping / development.
no setterinherited
-
account
→ _TranslationsAccountEs
-
latefinal
-
app_config
→ _TranslationsAppConfigEs
-
latefinal
-
auth
→ _TranslationsAuthEs
-
latefinal
-
common
→ _TranslationsCommonEs
-
latefinal
-
datetime
→ _TranslationsDatetimeEs
-
latefinal
-
device_info
→ _TranslationsDeviceInfoEs
-
latefinal
-
download
→ _TranslationsDownloadEs
-
latefinal
-
empty_view
→ _TranslationsEmptyViewEs
-
latefinal
-
error
→ _TranslationsErrorEs
-
latefinal
-
force_update
→ _TranslationsForceUpdateEs
-
latefinal
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
helpers
→ _TranslationsHelpersEs
-
latefinal
-
hivece_storage
→ _TranslationsHiveceStorageEs
-
latefinal
-
home
→ _TranslationsHomeEs
-
latefinal
-
image_detail
→ _TranslationsImageDetailEs
-
latefinal
-
loading
→ _TranslationsLoadingEs
-
latefinal
-
onboarding
→ _TranslationsOnboardingEs
-
latefinal
-
package_info
→ _TranslationsPackageInfoEs
-
latefinal
-
permissions
→ _TranslationsPermissionsEs
-
latefinal
-
permissions_helper
→ _TranslationsPermissionsHelperEs
-
latefinal
-
products
→ _TranslationsProductsEs
-
latefinal
-
profile
→ _TranslationsProfileEs
-
latefinal
-
push_notification
→ _TranslationsPushNotificationEs
-
latefinal
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
search
→ _TranslationsSearchEs
-
latefinal
-
settings
→ _TranslationsSettingsEs
-
latefinal
-
settings_widgets
→ _TranslationsSettingsWidgetsEs
-
latefinal
-
share
→ _TranslationsShareEs
-
latefinal
-
skeleton
→ _TranslationsSkeletonEs
-
latefinal
-
splash
→ _TranslationsSplashEs
-
latefinal
-
storage
→ _TranslationsStorageEs
-
latefinal
-
svg_helper
→ _TranslationsSvgHelperEs
-
latefinal
-
url_launcher
→ _TranslationsUrlLauncherEs
-
latefinal
-
web_viewer
→ _TranslationsWebViewerEs
-
latefinal