TranslationsTr class

Implemented types
Mixed-in types

Constructors

TranslationsTr({Map<String, Node>? overrides, PluralResolver? cardinalResolver, PluralResolver? ordinalResolver, TranslationMetadata<AppLocale, Translations>? meta})
You can call this constructor and build your own translation instance of this locale. Constructing via the enum AppLocale.build is preferred.

Properties

$meta TranslationMetadata<AppLocale, Translations>
Metadata for the translations of .
final
$wip → dynamic
Provides the ability to write plain strings without code generation. Useful for prototyping / development.
no setterinherited
account → _TranslationsAccountTr
latefinal
app_config → _TranslationsAppConfigTr
latefinal
auth → _TranslationsAuthTr
latefinal
common → _TranslationsCommonTr
latefinal
datetime → _TranslationsDatetimeTr
latefinal
device_info → _TranslationsDeviceInfoTr
latefinal
download → _TranslationsDownloadTr
latefinal
empty_view → _TranslationsEmptyViewTr
latefinal
error → _TranslationsErrorTr
latefinal
force_update → _TranslationsForceUpdateTr
latefinal
hashCode int
The hash code for this object.
no setterinherited
helpers → _TranslationsHelpersTr
latefinal
hivece_storage → _TranslationsHiveceStorageTr
latefinal
home → _TranslationsHomeTr
latefinal
image_detail → _TranslationsImageDetailTr
latefinal
loading → _TranslationsLoadingTr
latefinal
onboarding → _TranslationsOnboardingTr
latefinal
package_info → _TranslationsPackageInfoTr
latefinal
permissions → _TranslationsPermissionsTr
latefinal
permissions_helper → _TranslationsPermissionsHelperTr
latefinal
products → _TranslationsProductsTr
latefinal
profile → _TranslationsProfileTr
latefinal
push_notification → _TranslationsPushNotificationTr
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
latefinal
settings → _TranslationsSettingsTr
latefinal
settings_widgets → _TranslationsSettingsWidgetsTr
latefinal
share → _TranslationsShareTr
latefinal
skeleton → _TranslationsSkeletonTr
latefinal
splash → _TranslationsSplashTr
latefinal
storage → _TranslationsStorageTr
latefinal
svg_helper → _TranslationsSvgHelperTr
latefinal
url_launcher → _TranslationsUrlLauncherTr
latefinal
web_viewer → _TranslationsWebViewerTr
latefinal

Methods

$copyWith({TranslationMetadata<AppLocale, Translations>? meta}) TranslationsTr
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic
Access flat map
override