TranslationsAccountEn class

Properties

hashCode int
The hash code for this object.
no setterinherited
logout String
en: 'Logout'
no setter
profile String
en: 'Profile'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings String
en: 'Settings'
no setter
sign_out String
en: 'Sign Out'
no setter
title String
en: 'Account'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited