TranslationsHelpersEn class
Properties
- app_config → String
-
en: 'App Config'
no setter
- core_utilities → String
-
en: 'Core Utilities'
no setter
- date_time → String
-
en: 'Date & Time'
no setter
- device_info → String
-
en: 'Device Info'
no setter
- file_download → String
-
en: 'File Download'
no setter
- force_update → String
-
en: 'Force Update'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hivece → String
-
en: 'HiveCE'
no setter
- local_storage → String
-
en: 'Local Storage'
no setter
- package_info → String
-
en: 'Package Info'
no setter
- permissions → String
-
en: 'Permissions'
no setter
- push_notifications → String
-
en: 'Push Notifications'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
en: 'Share'
no setter
- skeleton_loading → String
-
en: 'Skeleton Loading'
no setter
- svg_helper → String
-
en: 'SVG Helper'
no setter
- title → String
-
en: 'Helpers'
no setter
- url_launcher → String
-
en: 'URL Launcher'
no setter
- web_viewer → String
-
en: 'Web Viewer'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited