TranslationsHiveceStorageEn class
Properties
- all_items → String
-
en: 'All Items'
no setter
- bool → String
-
en: 'Bool'
no setter
- double → String
-
en: 'Double'
no setter
- enter_key → String
-
en: 'enter key'
no setter
- false_value → String
-
en: 'false'
no setter
- get → String
-
en: 'Get'
no setter
- get_by_key → String
-
en: 'Get by Key'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- int → String
-
en: 'Int'
no setter
- key → String
-
en: 'key'
no setter
- list_hint → String
-
en: 'a, b, c'
no setter
- list_string → String
-
en: 'List
no setter
- no_items → String
-
en: 'No items'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- string → String
-
en: 'String'
no setter
- title → String
-
en: 'HiveCE Storage'
no setter
- true_value → String
-
en: 'true'
no setter
- value → String
-
en: 'value'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited