TranslationsSettingsEn class
Properties
- colors → String
-
en: 'Colors'
no setter
- dark → String
-
en: 'Dark'
no setter
- english → String
-
en: 'English'
no setter
- font_size → String
-
en: 'Font Size'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- icons → String
-
en: 'Icons'
no setter
- language → String
-
en: 'Language'
no setter
- light → String
-
en: 'Light'
no setter
- reset_to_defaults → String
-
en: 'Reset to Defaults'
no setter
- restore_theme_settings → String
-
en: 'Restore all theme settings'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spanish → String
-
en: 'Spanish'
no setter
- theme_mode → String
-
en: 'Theme Mode'
no setter
- title → String
-
en: 'Settings'
no setter
- turkish → String
-
en: 'Turkish'
no setter
- view_visibility → String
-
en: 'View Visibility'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited