TranslationsSvgHelperEn class
Properties
- asset_svg → String
-
en: 'Asset SVG'
no setter
- asset_svg_desc → String
-
en: 'Load SVG from assets folder'
no setter
- color_tinting → String
-
en: 'Color Tinting'
no setter
- color_tinting_desc → String
-
en: 'Change SVG color dynamically'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size_variations → String
-
en: 'Size Variations'
no setter
- size_variations_desc → String
-
en: 'Different icon sizes'
no setter
- svg_from_string → String
-
en: 'SVG from String'
no setter
- svg_from_string_desc → String
-
en: 'Render SVG from raw string data'
no setter
- themed_icon → String
-
en: 'Themed Icon'
no setter
- themed_icon_desc → String
-
en: 'Auto-colored from IconTheme'
no setter
- title → String
-
en: 'SVG Helper'
no setter
- using_svg_config → String
-
en: 'Using SvgConfig'
no setter
- using_svg_config_desc → String
-
en: 'Reusable configuration presets'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited