TranslationsUrlLauncherEn class
Properties
- email → String
-
en: 'Email'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- launch → String
-
en: 'Launch'
no setter
- phone → String
-
en: 'Phone'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sms → String
-
en: 'SMS'
no setter
- title → String
-
en: 'URL Launcher'
no setter
- url → String
-
en: 'URL'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited