TranslationsWebViewerEn class
Properties
- enter_url → String
-
en: 'Enter URL...'
no setter
- extract_links → String
-
en: 'Extract Links'
no setter
- extract_links_desc → String
-
en: 'htmlWidget.extractLinks()'
no setter
- extract_text → String
-
en: 'Extract Text'
no setter
- extract_text_desc → String
-
en: 'htmlWidget.extractText()'
no setter
- go → String
-
en: 'Go'
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- link_tapped → String
-
en: 'Link tapped: '
no setter
- no_links_found → String
-
en: 'No links found'
no setter
- preview → String
-
en: 'Preview'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sanitized_html → String
-
en: 'Sanitized HTML'
no setter
- sanitized_html_desc → String
-
en: 'WebViewerHelper.html() - Safe for user content'
no setter
-
en: 'Show Navigation: '
no setter
- style_presets → String
-
en: 'Style Presets'
no setter
- style_presets_desc → String
-
en: 'HtmlStyleConfig factory constructors'
no setter
- title → String
-
en: 'Web Viewer Helper'
no setter
- to_widget → String
-
en: 'To Widget'
no setter
- to_widget_desc → String
-
en: 'htmlWidget.toWidget()'
no setter
- web_url_viewer → String
-
en: 'Web URL Viewer'
no setter
- web_url_viewer_desc → String
-
en: 'WebViewerHelper.url() - Full WebView with navigation'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited